@@ -111,6 +111,11 @@ function suite.normalise_short_sha()
    assert(repo:normalise("8b50f4e"))
 end
 
+function suite.normalise_sha1ish()
+   local repo = test_repo()
+   assert(repo:normalise("refs/heads/master:testblob"))
+end
+
 function suite.error_normalise()
    local repo = test_repo()
    repo.path = "/DOES_NOT_EXIST"
